@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "richtextcomposer.h"
 #include "richtextexternalcomposer.h"
+#include "richtextcomposer.h"
 
-#include <KProcess>
-#include <KMacroExpander>
-#include <KShell>
 #include <KLocalizedString>
+#include <KMacroExpander>
 #include <KMessageBox>
+#include <KProcess>
+#include <KShell>
 #include <QTemporaryFile>
 
 using namespace KPIMTextEdit;
@@ -38,10 +38,7 @@ RichTextExternalComposer::RichTextExternalComposer(RichTextComposer *composer, Q
 {
 }
 
-RichTextExternalComposer::~RichTextExternalComposer()
-{
-    delete d;
-}
+RichTextExternalComposer::~RichTextExternalComposer() = default;
 
 bool RichTextExternalComposer::useExternalEditor() const
 {
@@ -106,11 +103,11 @@ void RichTextExternalComposer::startExternalEditor()
         }
 
         (*d->externalEditorProcess) << command;
-        if (!filenameAdded) {   // no %f in the editor command
+        if (!filenameAdded) { // no %f in the editor command
             (*d->externalEditorProcess) << d->extEditorTempFile->fileName();
         }
 
-        connect(d->externalEditorProcess, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &RichTextExternalComposer::slotEditorFinished);
+        connect(d->externalEditorProcess, &KProcess::finished, this, &RichTextExternalComposer::slotEditorFinished);
         d->externalEditorProcess->start();
         if (!d->externalEditorProcess->waitForStarted()) {
             d->cannotStartProcess(commandLine);
@@ -146,7 +143,7 @@ void RichTextExternalComposer::slotEditorFinished(int codeError, QProcess::ExitS
         Q_EMIT externalEditorClosed();
     }
 
-    killExternalEditor();   // cleanup...
+    killExternalEditor(); // cleanup...
 }
 
 bool RichTextExternalComposer::checkExternalEditorFinished()
@@ -155,16 +152,15 @@ bool RichTextExternalComposer::checkExternalEditorFinished()
         return true;
     }
 
-    const int ret = KMessageBox::warningYesNoCancel(
-        d->richTextComposer,
-        xi18nc("@info",
-               "The external editor is still running.<nl/>"
-               "Do you want to stop the editor or keep it running?<nl/>"
-               "<warning>Stopping the editor will cause all your "
-               "unsaved changes to be lost.</warning>"),
-        i18nc("@title:window", "External Editor Running"),
-        KGuiItem(i18nc("@action:button", "Stop Editor")),
-        KGuiItem(i18nc("@action:button", "Keep Editor Running")));
+    const int ret = KMessageBox::warningYesNoCancel(d->richTextComposer,
+                                                    xi18nc("@info",
+                                                           "The external editor is still running.<nl/>"
+                                                           "Do you want to stop the editor or keep it running?<nl/>"
+                                                           "<warning>Stopping the editor will cause all your "
+                                                           "unsaved changes to be lost.</warning>"),
+                                                    i18nc("@title:window", "External Editor Running"),
+                                                    KGuiItem(i18nc("@action:button", "Stop Editor")),
+                                                    KGuiItem(i18nc("@action:button", "Keep Editor Running")));
 
     switch (ret) {
     case KMessageBox::Yes:
