@@ -4,12 +4,12 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDITRICHTEXTEXTERNALCOMPOSER_H
-#define KPIMTEXTEDITRICHTEXTEXTERNALCOMPOSER_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 #include <QObject>
 #include <QProcess>
+#include <memory>
 
 namespace KPIMTextEdit
 {
@@ -44,8 +44,7 @@ Q_SIGNALS:
 private:
     void slotEditorFinished(int codeError, QProcess::ExitStatus exitStatus);
     class RichTextExternalComposerPrivate;
-    RichTextExternalComposerPrivate *const d;
+    std::unique_ptr<RichTextExternalComposerPrivate> const d;
 };
 }
 
-#endif // RICHTEXTEXTERNALCOMPOSER_H
