@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,14 +8,14 @@
 #include "tablecellformatdialog.h"
 
 #include <KColorButton>
-#include <QComboBox>
 #include <KLocalizedString>
 #include <KSeparator>
+#include <QComboBox>
 
 #include <QCheckBox>
+#include <QDialogButtonBox>
 #include <QLabel>
 #include <QVBoxLayout>
-#include <QDialogButtonBox>
 
 using namespace KPIMTextEdit;
 
@@ -26,10 +26,10 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Cell Format"));
-        auto *mainLayout = new QVBoxLayout;
+        auto mainLayout = new QVBoxLayout;
         q->setLayout(mainLayout);
 
-        auto *hbox = new QHBoxLayout;
+        auto hbox = new QHBoxLayout;
         QLabel *lab = new QLabel(i18n("Vertical Alignment:"));
         hbox->addWidget(lab);
         verticalAlignment = new QComboBox;
@@ -77,10 +77,7 @@ TableCellFormatDialog::TableCellFormatDialog(QWidget *parent)
 {
 }
 
-TableCellFormatDialog::~TableCellFormatDialog()
-{
-    delete d;
-}
+TableCellFormatDialog::~TableCellFormatDialog() = default;
 
 QColor TableCellFormatDialog::tableCellBackgroundColor() const
 {
@@ -95,9 +92,7 @@ void TableCellFormatDialog::setTableCellBackgroundColor(const QColor &col)
 
 QTextCharFormat::VerticalAlignment TableCellFormatDialog::verticalAlignment() const
 {
-    return
-        static_cast<QTextCharFormat::VerticalAlignment>(d->verticalAlignment->itemData(
-                                                            d->verticalAlignment->currentIndex()).toInt());
+    return static_cast<QTextCharFormat::VerticalAlignment>(d->verticalAlignment->itemData(d->verticalAlignment->currentIndex()).toInt());
 }
 
 void TableCellFormatDialog::setVerticalAlignment(QTextCharFormat::VerticalAlignment vertical)
