@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FINDUTILS_H
-#define FINDUTILS_H
+#pragma once
 
 #include <qglobal.h>
 
@@ -19,7 +18,7 @@ class TextReplaceWidget;
 namespace FindUtils
 {
 /**
- * Replaces all occurences of a search string provided by @p findWidget
+ * Replaces all occurrences of a search string provided by @p findWidget
  * by a string provided by @p replaceWidget in a @p document
  *
  * @return number of replacements done
@@ -28,4 +27,3 @@ Q_REQUIRED_RESULT int replaceAll(QTextDocument *document, const TextFindWidget *
 }
 } // namespace KPIMTextEdit
 
-#endif // FINDUTILS_H
