@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "texttospeechconfiggui.h"
-#include "texttospeech/texttospeechconfigwidget.h"
 #include "texttospeech/texttospeech.h"
+#include "texttospeech/texttospeechconfigwidget.h"
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QStandardPaths>
 #include <QHBoxLayout>
+#include <QStandardPaths>
 
 TextToSpeechConfigGui::TextToSpeechConfigGui(QWidget *parent)
     : QWidget(parent)
 {
-    auto *hbox = new QHBoxLayout(this);
-    auto *widget = new KPIMTextEdit::TextToSpeechConfigWidget(this);
+    auto hbox = new QHBoxLayout(this);
+    auto widget = new KPIMTextEdit::TextToSpeechConfigWidget(this);
     hbox->addWidget(widget);
 }
 
@@ -33,7 +33,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new TextToSpeechConfigGui;
+    auto w = new TextToSpeechConfigGui;
 
     w->show();
     app.exec();
